package organizer.components;


import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import organizer.AppInstance;
import organizer.images.Images;
import organizer.messages.Messages;

import echopointng.DateChooser;
import echopointng.model.CalendarEvent;
import echopointng.model.CalendarSelectionListener;
import echopointng.model.CalendarSelectionModel;
import echopointng.model.DefaultCalendarSelectionModel;
import nextapp.echo2.app.ApplicationInstance;
import nextapp.echo2.app.Button;
import nextapp.echo2.app.CheckBox;
import nextapp.echo2.app.Component;
import nextapp.echo2.app.Extent;
import nextapp.echo2.app.Grid;
import nextapp.echo2.app.Label;
import nextapp.echo2.app.RadioButton;
import nextapp.echo2.app.Row;
import nextapp.echo2.app.SelectField;
import nextapp.echo2.app.SplitPane;
import nextapp.echo2.app.TextArea;
import nextapp.echo2.app.TextField;
import nextapp.echo2.app.WindowPane;
import nextapp.echo2.app.button.ButtonGroup;
import nextapp.echo2.app.event.ActionEvent;
import nextapp.echo2.app.event.ActionListener;
import nextapp.echo2.extras.app.layout.TabPaneLayoutData;

public class TestWindow extends WindowPane
{
	
	private SimpleDateFormat dateFormat = new SimpleDateFormat(Messages.getMessage("DateFormat"), ApplicationInstance.getActive().getLocale());

	private TextField endField;
	private TextField startField;
	public static final String START_DATE_BUTTON_ID = "startDateButton";
	public static final String END_DATE_BUTTON_ID = "endDateButton";
	public TestWindow()
	{
		// Vytvorme SplitPane
		SplitPane meetingPane = new SplitPane(SplitPane.ORIENTATION_VERTICAL_BOTTOM_TOP,new Extent(30));
		// Objektom layout nastavme nzov zloky.
		TabPaneLayoutData layout = new TabPaneLayoutData();
		layout.setTitle(Messages.getMessage("AddWindow.Task"));
		meetingPane.setLayoutData(layout);
		/*==========================VYTVRANIE KOMPONENTOV==========================*/
		// Mrieka, do ktorej sa pridaj vektky komponenty
		Grid grid = new Grid(2);
		grid.setStyleName("Grid");
		
		// TextField pre nazov
		TextField nameField = new TextField();
		nameField.setStyleName("InputField");
		// Skupina pre radio buttony
		ButtonGroup buttonGroup = new ButtonGroup();
		// RadioButton pre ulohu, ktora sa pripravuje na riesenie
		RadioButton preparationState = new RadioButton();
		preparationState.setGroup(buttonGroup);
		// RadioButton pre uloha, ktora sa prave riesi
		RadioButton workingState = new RadioButton();
		workingState.setGroup(buttonGroup);
		// SelectField pre prioritu
		SelectField priority = createPriorityField();
		// CheckBox pre alarm
		CheckBox alarm = new CheckBox();
		// TextField pre zaiaton dtum
		startField = new TextField();
		startField.setStyleName("InputField");
		// TextField pre koneny dtum
		endField = new TextField();
		endField.setStyleName("InputField");
		// Label pre predmet		
		Label nameLabel = new Label(Messages.getMessage("TaskTab.Name"));
		nameLabel.setStyleName("InputLabel");
		// Label pre ulohu, ktora sa pripravuje na riesenie
		Label preparationLabel = new Label(Messages.getMessage("TaskTab.State.Preparation"));
		preparationLabel.setStyleName("InputLabel");
		// Label pre ulohu, ktora sa prave riesi
		Label workingLabel = new Label(Messages.getMessage("TaskTab.State.Working"));
		workingLabel.setStyleName("InputLabel");
		// Label pre prioritu ulohy
		Label priorityLabel = new Label(Messages.getMessage("TaskTab.Priority"));
		priorityLabel.setStyleName("InputLabel");
		// Label pre alarm
		Label alarmLabel = new Label(Messages.getMessage("TaskTab.Alarm"));
		alarmLabel.setStyleName("InputLabel");
		// Label pre zaiaton dtum
		Label startLabel = new Label(Messages.getMessage("TaskTab.Start"));
		startLabel.setStyleName("InputLabel");
		// Label pre koneny dtum
		Label endLabel = new Label(Messages.getMessage("TaskTab.End"));
		endLabel.setStyleName("InputLabel");
		// Tlaidlo pre kalendr, pre zaiaton dtum
		Button startDateButton = new Button();
		startDateButton.setIcon(Images.CALLENDAR_WINDOW_BUTTON);
		startDateButton.setId(START_DATE_BUTTON_ID);
		startDateButton.addActionListener(calendarListener);
		// Tlaidlo pre kalendr, pre konen dtum
		Button endDateButton = new Button();
		endDateButton.setIcon(Images.CALLENDAR_WINDOW_BUTTON);
		endDateButton.setId(END_DATE_BUTTON_ID);
		endDateButton.addActionListener(calendarListener);
		// Odosielacie tlaidlo
		Button submitButton = new Button();
		submitButton.setIcon(Images.SUBMIT_BUTTON);
		// Riadok pre obalenie startField a startDateButton
		Row startDateRow = new Row();
		//Riadok pre obalenie endField a endDateButton
		Row endDateRow = new Row();
		// Riadok pre obalenie radiobutton pre prvy typ ulohy
		Row preparationRow = new Row();
		// Riadok pre obalenie radiobutton pre druhy typ ulohy
		Row workingRow = new Row();
		// Riadok pre odosielacie tlaidlo
		Row buttonRow = new Row();
		buttonRow.setStyleName("SubmitButtonRow");
		
		/*==========================PRIDVANIE KOMPONENTOV==========================*/
		// Riadok pre obalenie startField a startFieldButton
		startDateRow.add(startField);
		startDateRow.add(startDateButton);  
		// Riadok pre obalenie endField a endDateButton
		endDateRow.add(endField);
		endDateRow.add(endDateButton);
		// Riadok pre obalenie radiobutton pre prvy typ ulohy
		preparationRow.add(preparationLabel);
		preparationRow.add(preparationState);
		// Riadok pre obalenie radiobutton pre druhy typ ulohy
		workingRow.add(workingLabel);
		workingRow.add(workingState);
		// Riadok pre odosielacie tlaidlo
		buttonRow.add(submitButton);
		// Komponenty pridme do mrieky	
		// 1. Riadok
		grid.add(nameLabel);
		grid.add(nameField);
		// 5. Riadok
		grid.add(startLabel);
		grid.add(startDateRow);
		// 6. Riadok
		grid.add(endLabel);
		grid.add(endDateRow);
		// 2. Riadok
		grid.add(preparationRow);
		grid.add(workingRow);
		
		// 3. Riadok
		grid.add(priorityLabel);
		grid.add(priority);
		// 4. Riadok
		grid.add(alarmLabel);
		grid.add(alarm);
		
		// Do objektu SplitPane vlome najrpv riadok s tlaidlom a potom mrieku
		meetingPane.add(buttonRow);
		meetingPane.add(grid);
		
		
		add(meetingPane);
	
	/* 
     * Pri vytvarani kalendarika skontrolujeme, ci uz nebol zadany v prislusnom input fielde nejaky
     * datum. Pokial ano tak ho v kalendari oznacime pokial nie odignorujeme exception.
     */
  
      
    ApplicationInstance.getActive().getDefaultWindow().getContent().add(this);  
}
/*==========================LISTENERS==========================*/

private SelectField createPriorityField() 
{
	Object[] items = new Object[11];
	for(int i=0;i<=10;i++)
	{
		items[i] = ""+i ;
	}
	
	SelectField field = new SelectField(items);
	field.setSelectedIndex(0);
	return field;
}
private ActionListener calendarListener = new ActionListener() 
{

	public void actionPerformed(ActionEvent ae) 
	{
		Button button = (Button) ae.getSource();
		String buttonId = button.getId();
		TextField field;
		if(buttonId.equals(START_DATE_BUTTON_ID))
		{
			field = startField;
		} else {
			field = endField;
		}

		AppInstance.getActive().getDefaultWindow().getContent().add(new DateWindow(field));
		
	}
	
};
}
